@@ -9,6 +9,11 @@
 #' return (only used for some models). See details for which methods this
 #' argument applies to.
 #'
+#' @param lambda Numeric value for the penalty parameter of a
+#' \code{\link[glmnet]{glmnet}} model (this is equivalent to the \code{s}
+#' argument in \code{\link[glmnet:predict.glmnet]{coef.glmnet}}). See the section on
+#' \code{\link[glmnet]{glmnet}} in the details below.
+#'
 #' @param ... Additional optional arguments to be passed on to other methods.
 #'
 #' @return A tidy data frame (i.e., a \code{"tibble"} object) with two columns:
@@ -35,7 +40,7 @@
 #' the option \code{metric = "usage"}. See \code{\link[C50]{C5imp}} for
 #' details.}
 #'
-#' \item{\code{\link[Cubist]{cubist}}}{The Cubist output contains variable usage
+#' \item{\code{\link[Cubist:cubist.default]{cubist}}}{The Cubist output contains variable usage
 #' statistics. It gives the percentage of times where each variable was used in
 #' a condition and/or a linear model. Note that this output will probably be
 #' inconsistent with the rules shown in the output from summary.cubist. At each
@@ -49,20 +54,21 @@
 #' to the terminal models shown in the output). The variable importance used
 #' here is a linear combination of the usage in the rule conditions and the
 #' model. See \code{\link[Cubist]{summary.cubist}} and
-#' \code{\link[caret]{varImp.cubist}} for details.}
+#' \code{\link[caret:varImp]{varImp.cubist}} for details.}
 #'
 #' \item{\code{\link[glmnet]{glmnet}}}{Similar to (generalized) linear models,
 #' the absolute value of the coefficients are returned for a specific model.
 #' It is important that the features  (and hence, the estimated coefficients) be
 #' standardized prior to fitting the model. You can specify which coefficients
 #' to return by passing the specific value of the penalty parameter via the
-#' \code{...} argument. See \code{\link[glmnet]{coef.glmnet}} for details. By
-#' default, the coefficients corresponding to the final penalty value in the
-#' sequence is returned; in other words, you should ALWAYS SPECIFY THIS VALUE!
-#' For \code{"cv.glmnet"} objects, the largest value of lambda such that error
-#' is within one standard error of the minimum is used by default. For
-#' \code{"multnet"} objects, the coefficients corresponding to the first class
-#' are used; that is, the fist component of \code{\link[glmnet]{coef.glmnet}}.}
+#' \code{lambda} argument (this is equivalent to the \code{s} argument in
+#' \code{\link[glmnet:predict.glmnet]{coef.glmnet}}). By default, \code{lambda = NULL} and the coefficients
+#' corresponding to the final penalty value in the sequence are returned; in
+#' other words, you should ALWAYS SPECIFY \code{lambda}! For \code{"cv.glmnet"}
+#' objects, the largest value of lambda such that the error is within one standard
+#' error of the minimum is used by default. For \code{"multnet"} objects, the
+#' coefficients corresponding to the first class are used; that is, the first
+#' component of \code{\link[glmnet:predict.glmnet]{coef.glmnet}}.}
 #'
 #' \item{\code{\link[partykit]{cforest}}}{Variable importance is measured in a
 #' way similar to those computed by \code{\link[randomForest]{importance}}.
@@ -140,7 +146,7 @@
 #'
 #' }}
 #'
-#' \item{\code{\link[h2o]{H2OModel}}}{See \code{\link[h2o]{h2o.varimp}} or visit
+#' \item{\code{\link[h2o:H2OModel-class]{H2OModel}}}{See \code{\link[h2o]{h2o.varimp}} or visit
 #' \url{http://docs.h2o.ai/h2o/latest-stable/h2o-docs/variable-importance.html}
 #' for details.}
 #'
@@ -192,13 +198,13 @@
 #'
 #' \item{\code{\link[party]{cforest}}}{Same approach described in
 #' \code{\link[partykit]{cforest}} above. See \code{\link[party]{varimp}} and
-#' \code{\link[party]{varimpAUC}} (if \code{type = "auc"}) for details.}
+#' \code{\link[party:varimp]{varimpAUC}} (if \code{type = "auc"}) for details.}
 #'
 #' \item{\code{\link[ranger]{ranger}}}{Variable importance for
 #' \code{\link[ranger]{ranger}} objects is computed in the usual way for random
 #' forests. The approach used depends on the \code{importance} argument provided
 #' in the initial call to \code{\link[ranger]{ranger}}. See
-#' \code{\link[ranger]{importance}} for details.}
+#' \code{\link[ranger:importance.ranger]{importance}} for details.}
 #'
 #' \item{\code{\link[rpart]{rpart}}}{As stated in one of the \strong{rpart}
 #' vignettes. A variable may appear in the tree many times, either as a primary
@@ -215,13 +221,13 @@
 #' call to \code{\link[caret]{train}}. See \code{\link[caret]{varImp}} for
 #' details.}
 #'
-#' \item{\code{\link[xgboost]{xgboost}}}{For linear models, the variable
+#' \item{\code{\link[xgboost:xgb.train]{xgboost}}}{For linear models, the variable
 #' importance is the absolute magnitude of the estimated coefficients. For that
 #' reason, in order to obtain a meaningful ranking by importance for a linear
 #' model, the features need to be on the same scale (which you also would want
 #' to do when using either L1 or L2 regularization). Otherwise, the approach
 #' described in Friedman (2001) for \code{\link[gbm]{gbm}}s is used. See
-#' \code{\link[xgboost]{xgb.importance}} for details. For tree models, you can
+#' \code{\link[xgboost:xgb.train]{xgb.importance}} for details. For tree models, you can
 #' obtain three different types of variable importance:
 #' \itemize{
 #'
@@ -444,14 +450,14 @@ vi_model.gbm <- function(object, type = c("relative.influence", "permutation"),
 #' @rdname vi_model
 #'
 #' @export
-vi_model.glmnet <- function(object, ...) {
+vi_model.glmnet <- function(object, lambda = NULL, ...) {
 
   # Extract coefficients
-  s <- list(...)$s
-  if (is.null(s)) {
-    s <- min(object$lambda)
+  #s <- list(...)$s
+  if (is.null(lambda)) {
+    lambda <- min(object$lambda)
   }
-  coefs <- stats::coef(object, s = s)
+  coefs <- stats::coef(object, s = lambda)
   if (inherits(coefs, what = "list")) {  # "multnet" objects
     coefs <- coefs[[1L]]
   }
@@ -465,7 +471,7 @@ vi_model.glmnet <- function(object, ...) {
   # Construct model-specific variable importance scores
   tib <- tibble::tibble(
     "Variable" = names(coefs),
-    "Importance" = unname(coefs),  # per tibble 3.0.0
+    "Importance" = unname(abs(coefs)),  # per tibble 3.0.0
     "Sign" = ifelse(sign(coefs) == 1, yes = "POS", no = "NEG")
   )
 
@@ -484,14 +490,14 @@ vi_model.glmnet <- function(object, ...) {
 #' @rdname vi_model
 #'
 #' @export
-vi_model.cv.glmnet <- function(object, ...) {
+vi_model.cv.glmnet <- function(object, lambda = NULL, ...) {
 
   # Extract coefficients
-  s <- list(...)$s
-  if (is.null(s)) {
-    s <- "lambda.1se"
+  #s <- list(...)$s
+  if (is.null(lambda)) {
+    lambda <- "lambda.1se"
   }
-  coefs <- stats::coef(object, s = s)
+  coefs <- stats::coef(object, s = lambda)
   if (inherits(coefs, what = "list")) {  # "multnet" objects
     coefs <- coefs[[1L]]
   }
@@ -505,7 +511,7 @@ vi_model.cv.glmnet <- function(object, ...) {
   # Construct model-specific variable importance scores
   tib <- tibble::tibble(
     "Variable" = names(coefs),
-    "Importance" = unname(coefs),
+    "Importance" = unname(abs(coefs)),
     "Sign" = ifelse(sign(coefs) == 1, yes = "POS", no = "NEG")
   )
 
@@ -529,7 +535,7 @@ vi_model.cv.glmnet <- function(object, ...) {
 vi_model.H2OBinomialModel <- function(object, ...) {
 
   # Construct model-specific variable importance scores
-  tib <- tibble::as.tibble(h2o::h2o.varimp(object))
+  tib <- tibble::as_tibble(h2o::h2o.varimp(object))
   if (object@algorithm == "glm") {
     names(tib) <- c("Variable", "Importance", "Sign")
     # FIXME: Extra row at the bottom?
@@ -556,7 +562,7 @@ vi_model.H2OBinomialModel <- function(object, ...) {
 vi_model.H2OMultinomialModel <- function(object, ...) {
 
   # Construct model-specific variable importance scores
-  tib <- tibble::as.tibble(h2o::h2o.varimp(object))
+  tib <- tibble::as_tibble(h2o::h2o.varimp(object))
   if (object@algorithm == "glm") {
     names(tib) <- c("Variable", "Importance", "Sign")
     # FIXME: Extra row at the bottom?
@@ -583,7 +589,7 @@ vi_model.H2OMultinomialModel <- function(object, ...) {
 vi_model.H2ORegressionModel <- function(object, ...) {
 
   # Construct model-specific variable importance scores
-  tib <- tibble::as.tibble(h2o::h2o.varimp(object))
+  tib <- tibble::as_tibble(h2o::h2o.varimp(object))
   if (object@algorithm == "glm") {
     names(tib) <- c("Variable", "Importance", "Sign")
     # FIXME: Extra row at the bottom?
@@ -1319,7 +1325,7 @@ vi_model.xgb.Booster <- function(object, type = c("gain", "cover", "frequency"),
   if ("weight" %in% names(imp)) {
     type <- "weight"  # gblinear
   }
-  vis <- tibble::as.tibble(imp)[, c("feature", type)]
+  vis <- tibble::as_tibble(imp)[, c("feature", type)]
   tib <- tibble::tibble(
     "Variable" = vis$feature,
     "Importance" = vis[[2L]]
